/* ANCHOR: all */
# Ceremony Repository

// ANCHOR: content
This repository holds data pertaining to ceremonies. The primary data consists of:

* Transaction proposals

* Transaction approvals

* Trusted PGP keyring

* Shardfile

* Policies (such as spending rules)

* Ceremony logs 

## Directives

* MUST be a private repository

* MUST be write protected, requiring approval from at least 1 individual other than one who opened the PR for merging

* MUST require signed commits

## Repository Structure

```
keys/
    all/
        fingerprint.asc
<namespace>/
    ceremonies/
        <date>/
            log.txt
            payloads/
                payload_<num>.json
                payload_<num>.json.sig
    blockchain_metadata/
        sol_nonce_address.txt
    policies/
        spending-policy.json [NOT IMPLEMENTED]
    keyring.asc
    shardfile.asc
```

## Procedure: Setting up Repository

{{ #include ./git-repository-initialization.md:procedure}}

## Procedure: Adding a OpenPGP Public Certificate

1. Ensure you are on the correct branch:

    * `git checkout main`

1. Pull the latest ceremony repo changes

    * `git pull origin main`

1. Find your key fingerprint:

    `gpg --list-keys`

1. Export your OpenPGP public certificate:

    * `gpg --export --armor <key_fingerprint> > <key_fingerprint>.asc

1. Place the file in `keys/all/<key_fingerprint>.asc`

1. Create signed git commit:

    * `git commit -m "add <name> pgp key"`

1. Push to the commit:

    * `git push origin main`

1. Communicate your new key fingerprint to all other participants:

    * Preferred: In person 
    
    * Fallback: via two logically distinct online communications methods (e.g. encrypted chat, and video call)

1. Get confirmation they have used `gpg --import <your_key_id>.asc` to import your key from the git repo to the keyrings on workstations they will use to interact with the ceremony repo

// ANCHOR_END: content
/* ANCHOR_END: all */

